/**
   This class provides support for message logging and
   assertion checking.
*/
public class Logger
{
   /**
      Logs a message. In debug mode, the message and a stack 
      trace are printed.
      @message the message to print
   */
   public void log(String message)
   {
      if (debug)
      {
         System.out.println(message);
         Throwable t = new Throwable();
         t.printStackTrace(System.out);
         System.out.println();
      }
   }

   /**
      Checks for an assertion. In debug mode,  
      a message and a stack trace are printed 
      and the program exits if the condition is false.
      @condition the condition to check.
   */
   public void assert(boolean condition)
   {
      if (debug && !condition)
      {
         System.out.println("Assertion failure");
         Throwable t = new Throwable();
         t.printStackTrace(System.out);
         System.exit(0);
      }
   }

   /**
      Sets the debug mode for assertion reporting
      @param b true to activate logging, false to deactivate
   */
   public void setDebug(boolean b)
   {
      debug = b;
   }
      
   private boolean debug = true;
}
