import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Random;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;

/**
   This frame has a menu with commands to set the position of
   a rectangle.
*/
class MenuFrame extends JFrame
{ 
   /**
      Constructs the frame.
   */
   public MenuFrame()
   {  
      generator = new Random();

      // add drawing panel to content pane
      
      panel = new RectanglePanel();
      getContentPane().add(panel, BorderLayout.CENTER);   
      pack();
      
      // construct menu
      
      JMenuBar menuBar = new JMenuBar();     
      setJMenuBar(menuBar);

      menuBar.add(createFileMenu());
      menuBar.add(createEditMenu());
   }

   /**
      Creates the File menu.
      @return the menu
   */
   public JMenu createFileMenu()
   {
      JMenu menu = new JMenu("File");
      menu.add(createFileNewItem());
      menu.add(createFileExitItem());
      return menu;
   }

   /**
      Creates the Edit menu.
      @return the menu
   */
   public JMenu createEditMenu()
   {
      JMenu menu = new JMenu("Edit");
      menu.add(createMoveMenu());
      menu.add(createEditRandomizeItem());
      return menu;
   }

   /**
      Creates the Move submenu.
      @return the menu
   */
   public JMenu createMoveMenu()
   {
      JMenu menu = new JMenu("Move");
      menu.add(createMoveItem("Up", 0, -1));
      menu.add(createMoveItem("Down", 0, 1));
      menu.add(createMoveItem("Left", -1, 0));
      menu.add(createMoveItem("Right", 1, 0));
      return menu;
   }  

   /**
      Creates the File->New menu item and sets its action listener.
      @return the menu item
   */
   public JMenuItem createFileNewItem()
   {
      JMenuItem item = new JMenuItem("New");      
      class MenuItemListener implements ActionListener
      {
         public void actionPerformed(ActionEvent event)
         {
            panel.reset();
         }
      }      
      ActionListener listener = new MenuItemListener();
      item.addActionListener(listener);
      return item;
   }
   
   /**
      Creates the File->Exit menu item and sets its action listener.
      @return the menu item
   */
   public JMenuItem createFileExitItem()
   {
      JMenuItem item = new JMenuItem("Exit");      
      class MenuItemListener implements ActionListener
      {
         public void actionPerformed(ActionEvent event)
         {
            System.exit(0);
         }
      }      
      ActionListener listener = new MenuItemListener();
      item.addActionListener(listener);
      return item;
   }

   /**
      Creates a menu item to move the rectangle and sets its 
      action listener.
      @param label the menu label
      @param dx the amount by which to move the rectangle in x-direction
      @param dy the amount by which to move the rectangle in y-direction
      @return the menu item
   */
   public JMenuItem createMoveItem(String label,
      final int dx, final int dy)
   {
      JMenuItem item = new JMenuItem(label);      
      class MenuItemListener implements ActionListener
      {
         public void actionPerformed(ActionEvent event)
         {
            panel.moveRectangle(dx, dy);
         }
      }      
      ActionListener listener = new MenuItemListener();
      item.addActionListener(listener);
      return item;
   }

   /**
      Creates the Edit->Randomize menu item and sets its action listener.
      @return the menu item
   */
   public JMenuItem createEditRandomizeItem()
   {
      JMenuItem item = new JMenuItem("Randomize");      
      class MenuItemListener implements ActionListener
      {
         public void actionPerformed(ActionEvent event)
         {
            int width = panel.getWidth();
            int height = panel.getHeight();
            int dx = -1 + generator.nextInt(2);
            int dy = -1 + generator.nextInt(2);
            panel.moveRectangle(dx, dy);
         }
      }      
      ActionListener listener = new MenuItemListener();
      item.addActionListener(listener);
      return item;
   }

   private RectanglePanel panel;
   private Random generator;
}




