import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import javax.swing.JPanel;

/**
   A panel that shows a rectangle.
*/
class RectanglePanel extends JPanel
{ 
   /**
      Constructs a panel with the rectangle in the top left 
      corner.
   */
   public RectanglePanel()
   {  
      setPreferredSize(new Dimension(PANEL_WIDTH, PANEL_HEIGHT));
      // the rectangle that the paint method draws
      box = new Rectangle(0, 0, BOX_WIDTH, BOX_HEIGHT);
   }
   
   public void paintComponent(Graphics g)
   {  
      super.paintComponent(g);
      Graphics2D g2 = (Graphics2D)g;
      g2.draw(box);
   }
   
   /**
      Resets the rectangle to the top left corner.
   */
   public void reset()
   {  
      box.setLocation(0, 0);
      repaint();
   }
   
   /**
      Moves the rectangle and repaints it. The rectangle 
      is moved by multiples of its full width or height.
      @param dx the number of width units
      @param dy the number of height units
   */   
   public void moveRectangle(int dx, int dy)
   {  
      box.translate(dx * BOX_WIDTH, dy * BOX_HEIGHT);
      repaint();
   }
   
   private Rectangle box;
   private static final int BOX_WIDTH = 20;
   private static final int BOX_HEIGHT = 30;
   private static final int PANEL_WIDTH = 300;
   private static final int PANEL_HEIGHT = 300;
}

