import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import javax.swing.JPanel;

/**
   A rectangle panel displays a rectangle that a user can
   move by clicking the mouse.
*/
public class RectanglePanel extends JPanel
{  
   /**
      Constructs a rectangle panel with the rectangle at a 
      default location.
   */
   public RectanglePanel()
   {  
      setPreferredSize(new Dimension(PANEL_WIDTH, PANEL_HEIGHT));

      // the rectangle that the paint method draws
      box = new Rectangle(BOX_X, BOX_Y, 
         BOX_WIDTH, BOX_HEIGHT);

      // add mouse press listener         

      class MousePressListener implements MouseListener
      {  
         public void mousePressed(MouseEvent event)
         {  
            int x = event.getX();
            int y = event.getY();
            box.setLocation(x, y);
            repaint();
         }

         // do-nothing methods
         public void mouseReleased(MouseEvent event) {}
         public void mouseClicked(MouseEvent event) {}
         public void mouseEntered(MouseEvent event) {}
         public void mouseExited(MouseEvent event) {}
      }
         
      MouseListener listener = new MousePressListener();
      addMouseListener(listener);
   }

   public void paintComponent(Graphics g)
   {  
      super.paintComponent(g);
      Graphics2D g2 = (Graphics2D)g;
      g2.draw(box);
   }

   private Rectangle box;
   private static final int BOX_X = 100;
   private static final int BOX_Y = 100;
   private static final int BOX_WIDTH = 20;
   private static final int BOX_HEIGHT = 30;

   private static final int PANEL_WIDTH = 300;
   private static final int PANEL_HEIGHT = 300;
}
