import java.util.ArrayList;

/**
   A purse holds a collection of coins.
*/
public class Purse
{
   /**
      Constructs an empty purse.
   */
   public Purse()
   {
      coins = new ArrayList();
   }

   /**
      Add a coin to the purse.
      @param aCoin the coin to add
   */
   public void add(Coin aCoin)
   {
      coins.add(aCoin);
   }

   /**
      Get the total value of the coins in the purse.
      @return the sum of all coin values
   */
   public double getTotal()
   {
      double total = 0;
      for (int i = 0; i < coins.size(); i++)
      {
         Coin aCoin = (Coin)coins.get(i);
         total = total + aCoin.getValue();       
      }
      return total;
   }

   /**
      Counts the number of coins in the purse
      @return the number of coins
   */
   public int count()
   {
      return coins.size();
   }

   /**
      Tests if the purse has a coin that matches
      a given coin.
      @param aCoin the coin to match
      @return true if there is a coin equal to aCoin
   */
   public boolean find(Coin aCoin)
   {
      for (int i = 0; i < coins.size(); i++)
      {
         Coin c = (Coin)coins.get(i);
         if (c.equals(aCoin)) return true; // found a match
      }
      return false; // no match in the entire array list
   }

   /**
      Counts the number of coins in the purse that match
      a given coin.
      @param aCoin the coin to match
      @return the number of coins equal to aCoin
   */
   public int count(Coin aCoin)
   {
      int matches = 0;
      for (int i = 0; i < coins.size(); i++)
      {
         Coin c = (Coin)coins.get(i);
         if (c.equals(aCoin)) matches++; // found a match
      }
      return matches;
   }

   /**
      Finds the coin with the largest value. 
      (Precondition: The purse is not empty)
      @return a coin with maximum value in this purse
   */
   Coin getMaximum()
   {
      Coin max = (Coin)coins.get(0);
      for (int i = 1; i < coins.size(); i++) 
      {
         Coin c = (Coin)coins.get(i);
         if (c.getValue() > max.getValue())
            max = c;
      }
      return max;
   }

   private ArrayList coins;
}

