import java.io.BufferedReader;
import java.io.EOFException;
import java.io.IOException;

/**
   A coin with a monetary value.
*/
public class Coin
{
   /**
      Constructs a default coin.
      Use the read method to fill in the value and name.
   */
   public Coin()
   {
      value = 0;
      name = "";
   }

   /**
      Constructs a coin.
      @param aValue the monetary value of the coin.
      @param aName the name of the coin
   */
   public Coin(double aValue, String aName) 
   { 
      value = aValue; 
      name = aName;
   }

   /**
      Reads a coin value and name.
      @param in the reader
      @return true if the data was read, 
      false if the end of the stream was reached
   */
   public boolean read(BufferedReader in) 
      throws IOException
   {  
      String input = in.readLine();
      if (input == null) return false;
      value = Double.parseDouble(input);
      name = in.readLine();
      if (name == null) 
         throw new EOFException("Coin name expected");
      return true;
   }

   /**
      Gets the coin value.
      @return the value
   */
   public double getValue() 
   {
      return value;
   }

   /**
      Gets the coin name.
      @return the name
   */
   public String getName() 
   {
      return name;
   }

   private double value;
   private String name;
}









