import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;

/**
   A purse computes the total of a collection of coins.
*/
public class Purse
{
   /**
      Constructs an empty purse.
   */
   public Purse()
   {
      total = 0;
   }

   /**
      Read a file with coin descriptions and adds the coins
      to the purse.
      @param filename the name of the file
   */
   public void readFile(String filename)
      throws IOException
   {
      BufferedReader in = null;
      try
      {  
         in = new BufferedReader(new FileReader(filename));
         read(in);
      }
      finally
      {
         if (in != null) in.close();
      }
   }

   /**
      Read a file with coin descriptions and adds the coins
      to the purse.
      @param in the buffered reader for reading the input
   */
   public void read(BufferedReader in) 
      throws IOException
   {  
      boolean done = false;
      while (!done)
      {
         Coin c = new Coin();
         if (c.read(in))
            add(c);
         else
            done = true;
      }
   }

   /**
      Add a coin to the purse.
      @param aCoin the coin to add
   */
   public void add(Coin aCoin)
   {
      total = total + aCoin.getValue();
   }

   /**
      Get the total value of the coins in the purse.
      @return the sum of all coin values
   */
   public double getTotal()
   {
      return total;
   }

   private double total;
}

