import java.io.IOException;
import java.io.RandomAccessFile;

/**
   This class is a conduit to a random access file
   containing savings account data.
*/
public class BankData
{
   /**
      Constructs a BankData object that is not associated
      with a file.
   */
   public BankData()
   {
      file = null;
   }

   /**
      Opens the data file.
      @param filename the name of the file containing savings
      account information.
   */
   public void open(String filename)
      throws IOException
   {
      if (file != null) file.close();
      file = new RandomAccessFile(filename, "rw");;
   }

   /**
      Gets the number of accounts in the file.
      @return the number of accounts.
   */
   public int size()
      throws IOException
   {
      return (int)(file.length() / RECORD_SIZE);
   }

   /**
      Closes the data file.
   */
   public void close()
      throws IOException
   {
      if (file != null) file.close();
      file = null;
   }

   /**
      Reads a savings account record.
      @param n the index of the account in the data file
      @return a savings account object initialized with the file data
   */
   public SavingsAccount read(int n)
      throws IOException
   {  
      file.seek(n * RECORD_SIZE);      
      double balance = file.readDouble();
      double interestRate = file.readDouble();
      SavingsAccount account = new SavingsAccount(interestRate);
      account.deposit(balance);
      return account;
   }

   /**
      Writes a savings account record to the data file
      @param n the index of the account in the data file
      @param account the account to write
   */
   public void write(int n, SavingsAccount account)
      throws IOException
   {  
      file.seek(n * RECORD_SIZE);
      file.writeDouble(account.getBalance());
      file.writeDouble(account.getInterestRate());
   }

   private RandomAccessFile file;

   public static final int DOUBLE_SIZE = 8;  
   public static final int RECORD_SIZE 
      = 2 * DOUBLE_SIZE;
}
