import java.util.ArrayList;

/**
   Describes an invoice for a set of purchased products.
*/
class Invoice
{  
   /**
      Constructs an invoice.
      @param anAddress the billing address
   */
   public Invoice(Address anAddress)
   {  
      items = new ArrayList();
      billingAddress = anAddress;
   }
  
   /**
      Adds a charge for a product to this invoice.
      @param aProduct the product that the customer ordered
      @param quantity the quantity of the product
   */
   public void add(Product aProduct, int quantity)
   {  
      Item anItem = new Item(aProduct, quantity);
      items.add(anItem);
   }

   /**
      Formats the invoice.
      @return the formatted invoice
   */
   public String format()
   {  
      String r =  "                     I N V O I C E\n\n"
         + billingAddress.format()
         + "\n\nDescription                   Price  Qty  Total\n";
      for (int i = 0; i < items.size(); i++)
      {  
         Item nextItem = (Item)items.get(i);
         r = r + nextItem.format() + "\n";
      }

      r = r + "\nAMOUNT DUE: $" + getAmountDue();

      return r;
   }

   /**
      Computes the total amount due.
      @return the amount due
   */
   public double getAmountDue()
   {  
      double amountDue = 0;
      for (int i = 0; i < items.size(); i++)
      {  
         Item nextItem = (Item)items.get(i);
         amountDue = amountDue + nextItem.getTotalPrice();
      }
      return amountDue;
   }
   
   private Address billingAddress;
   private ArrayList items;
}
