import java.applet.Applet;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.event.MouseEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseListener;

/**
   This applet animates the selection sort algorithm.
*/
public class SelectionSortApplet extends Applet
{
   /**
      Constructs the applet and sets up the mouse handler.
      Click on the surface of the applet to start the animation.
   */
   public SelectionSortApplet()
   {
      class MousePressListener extends MouseAdapter
      {
         public void mousePressed(MouseEvent event)
         {
            if (animation != null && animation.isAlive()) 
               animation.interrupt();
            startAnimation();
         }
      }

      MouseListener listener = new MousePressListener();
      addMouseListener(listener);
      setBackground(Color.lightGray);

      sorter = null;
      animation = null;
   }

   public void paint(Graphics g)
   {
      if (sorter == null) return;
      Graphics2D g2 = (Graphics2D)g;
      sorter.draw(g2);
   }

   /**
      Starts a new animation thread.
   */
   public void startAnimation()
   {
      class AnimationThread extends Thread
      {
         public void run()
         {
            try
            {
               sorter.sort();
            }
            catch (InterruptedException exception)
            {
            }
         }
      }
      
      int[] values = ArrayUtil.randomIntArray(30, 300);
      sorter = new SelectionSorter(values, this);
      animation = new AnimationThread();
      animation.start();
   }

   private SelectionSorter sorter;
   private Thread animation;
}

