import java.applet.Applet;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.geom.Line2D;

/**
   This class sorts an array, using the selection sort 
   algorithm
*/
public class SelectionSorter
{
   /**
      Constructs a selection sorter.
      @param anArray the array to sort.
   */
   public SelectionSorter(int[] anArray, Applet anApplet)
   {
      a = anArray;
      applet = anApplet;
   }

   /**
      Sorts the array managed by this selection sorter.
   */
   public void sort() 
      throws InterruptedException
   {  
      for (int i = 0; i < a.length - 1; i++)
      {  
         int minPos = minimumPosition(i);
         swap(minPos, i);
         // for animation
         alreadySorted = i;
         pause(2);
      }
   }

   /**
      Finds the smallest element in a tail range of the array
      @param from the first position in a to compare
      @return the position of the smallest element in the
      range a[from]...a[a.length - 1]
   */
   private int minimumPosition(int from)
      throws InterruptedException
   {  
      int minPos = from;
      for (int i = from + 1; i < a.length; i++)
      {
         if (a[i] < a[minPos]) minPos = i;
         // for animation
         markedPosition = i;
         pause(2);
      }
      return minPos;
   }

   /**
      Swaps two entries of the array.
      @param i the first position to swap
      @param j the second position to swap
   */
   private void swap(int i, int j)
   {
      int temp = a[i];
      a[i] = a[j];
      a[j] = temp;
   }

   /**
      Draws the current state of the sorting algorithm.
      @param g2 the graphics context
   */
   public void draw(Graphics2D g2)
   {
      int deltaX = applet.getWidth() / a.length;
      for (int i = 0; i < a.length; i++)
      {
         if (i == markedPosition)
            g2.setColor(Color.red);
         else if (i <= alreadySorted)
            g2.setColor(Color.blue);
         else
            g2.setColor(Color.black);
         g2.draw(new Line2D.Double(i * deltaX, 0, 
            i * deltaX, a[i]));
      }
   }

   /**
      Pauses the animation.
      @param steps the number of steps to pause
   */
   public void pause(int steps) 
      throws InterruptedException
   {
      if (Thread.currentThread().isInterrupted()) 
         throw new InterruptedException();
      applet.repaint();
      Thread.sleep(steps * DELAY);
   }

   private int[] a;

   // the applet is needed for pausing the animation
   private Applet applet;   
   
   // these fields are needed for drawing 
   private int markedPosition = -1;
   private int alreadySorted = -1;

   private static final int DELAY = 100;
}
