import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.net.Socket;
import java.util.StringTokenizer;

/**
   Executes Simple Bank Access Protocol commands
   from a socket.
*/
public class BankService
{
   /**
      Constructs a service object that processes commands
      from a socket for a bank.
      @param aSocket the socket
      @param aBank the bank
   */
   public BankService(Socket aSocket, Bank aBank)
   {
      s = aSocket;
      bank = aBank;
   }

   /**
      Executes all commands until the QUIT command or the
      end of input.
   */
   public void doService() throws IOException
   {
      BufferedReader in = new BufferedReader(
         new InputStreamReader(s.getInputStream()));
      PrintWriter out = new PrintWriter(
         s.getOutputStream());
      
      while (true)
      {  
         String line = in.readLine();
         System.out.println("Received: " + line);
         if (line == null || line.equals("QUIT")) 
            return;

         String response = executeCommand(line);

         System.out.println("Sending: " + response);
         out.println(response);
         out.flush();
      }
   }

   /**
      Executes a single command.
      @param line the command
      @return the reply to send to the client.
   */
   public String executeCommand(String line)
   {
      StringTokenizer tokenizer 
         = new StringTokenizer(line);
      String command = tokenizer.nextToken();
      int account = Integer.parseInt(tokenizer.nextToken());
      if (command.equals("DEPOSIT"))
      {
         double amount = Double.parseDouble(
            tokenizer.nextToken());
         bank.deposit(account, amount);
      }
      else if (command.equals("WITHDRAW"))
      {
         double amount = Double.parseDouble(
            tokenizer.nextToken());
         bank.withdraw(account, amount);
      }      
      else if (!command.equals("BALANCE"))
         return "Invalid command";

      return account + " " + bank.getBalance(account);
   }

   private Socket s;
   private Bank bank;
}
