import java.net.*;
import java.sql.*;
import java.io.*;
import java.util.*;

class ExecSQL
{
   /**
      Executes all SQL statements in a file
      @param args 
      <ul>
      <li>args[0]: the property file for the database connection</li>
      <li>args[1]: the file with SQL statements</li>
      </ul>
    */
   public static void main (String args[])
   {   
      try
      {  
         if (args.length == 0)
         {   
            System.out.println
               ("Usage: ExecSQL propertyFile [statementFile]");
            System.exit(0);
         }
         Connection con = getConnection(args[0]);
         Statement stmt = con.createStatement();
         

         String tableName = "";

         Reader reader;
         if (args.length > 1) 
            reader = new FileReader(args[1]);
         else
            reader = new InputStreamReader(System.in);
         BufferedReader in = new BufferedReader(reader);


         String line;
         while ((line = in.readLine()) != null)
         {
            boolean hasResultSet = stmt.execute(line);
            if (hasResultSet)
               showResultSet(stmt);
         }

         in.close();
         stmt.close();
         con.close();
      }
      catch (SQLException ex)
      {  
         System.out.println ("SQLException:");
         while (ex != null)
         {  
            System.out.println ("SQLState: "
               + ex.getSQLState());
            System.out.println ("Message:  "
               + ex.getMessage());
            System.out.println ("Vendor:   "
               + ex.getErrorCode());
            ex = ex.getNextException();
            System.out.println ("");
         }
      }
      catch (IOException ex)
      {  
         System.out.println("IOException: " + ex);
         ex.printStackTrace ();
      }
   }

   /**
      Opens a database connection
      @param fileName the name of the property file that contains the
      database driver, url, username and password
      @return the connection to the database
    */
   public static Connection getConnection(String fileName)
      throws SQLException, IOException
   {  
      Properties props = new Properties();
      FileInputStream in = new FileInputStream(fileName);
      props.load(in);

      String drivers = props.getProperty("jdbc.drivers");
      if (drivers != null)
         System.setProperty("jdbc.drivers", drivers);
      String url = props.getProperty("jdbc.url");
      String username = props.getProperty("jdbc.username");
      String password = props.getProperty("jdbc.password");
      
      return
         DriverManager.getConnection(url, username, password);
   }

   public static void showResultSet(Statement stmt) 
      throws SQLException
   { 
      ResultSet rs = stmt.getResultSet();
      ResultSetMetaData rsmd = rs.getMetaData();
      int columnCount = rsmd.getColumnCount();
      while (rs.next())
      {  
         for (int i = 1; i <= columnCount; i++)
         {  
            if (i > 1) System.out.print(", ");
            System.out.print(rs.getString(i));
         }
         System.out.println();
      }
      rs.close();
   }
}
