import java.text.DateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.TimeZone;

/**
   This bean formats the local times of day for a given date
   and list of cities.
*/
public class MultiZoneBean
{ 
   /**
      Initializes the formatter and city list.
   */
   public MultiZoneBean()
   {
      timeFormatter = DateFormat.getTimeInstance();
      cities = new ArrayList();
   }

   /**
      Write-only date property. 
      @param aDate the date to be formatted.
   */
   public void setDate(Date aDate)
   {
      theDate = aDate;
   }

   /**
      Write-only city property. 
      @param aCity the city to add to the city list
   */
   public void setCity(String aCity)
   {
      cities.add(aCity);
   }

   /**
      Read-only times property.
      @return a string containing the HTML code for an unnumbered
      list of cities and local times
   */
   public String getTimes()
   {
      StringBuffer buffer = new StringBuffer();
      for (int i = 0; i < cities.size(); i++)
      {
         String city = (String)cities.get(i);

         buffer.append("<li>");
         buffer.append(city);
         buffer.append(": ");

         TimeZone zone = getTimeZone(city);
         if (zone == null) 
            buffer.append("not available");
         else
         { 
            timeFormatter.setTimeZone(zone);
            String timeString = timeFormatter.format(theDate);
            buffer.append(timeString);
         }
         buffer.append("</li>");            
      }
      return buffer.toString();
   }

   /**
      Looks up the time zone for a city
      @param aCity the city for which to find the time zone
      @return the time zone or null if no match is found
   */
   private static TimeZone getTimeZone(String city)
   {
      String[] ids = TimeZone.getAvailableIDs();
      for (int i = 0; i < ids.length; i++)
         if (timeZoneIDmatch(ids[i], city))
            return TimeZone.getTimeZone(ids[i]);
      return null;
   }

   /**
      Checks whether a time zone ID matches a city
      @param id the time zone ID (e.g. "America/Los_Angeles")
      @param aCity the city to match (e.g. "Los Angeles")
      @return true if the ID and city match
   */
   private static boolean timeZoneIDmatch(String id, String city)
   {
      String idCity = id.substring(id.indexOf('/') + 1);
      return idCity.replace('_', ' ').equals(city);
   }

   private DateFormat timeFormatter;
   private Date theDate;
   private ArrayList cities;
}

