import java.text.DateFormat;
import java.util.Date;
import java.util.TimeZone;

/**
   This bean formats the local time of day for a given date
   and city.
*/
public class TimeZoneBean
{
   /**
      Initializes the formatter.
   */
   public TimeZoneBean()
   {
      timeFormatter = DateFormat.getTimeInstance();
   }

   /**
      Write-only date property. 
      @param aDate the date to be formatted.
   */
   public void setDate(Date aDate)
   {
      theDate = aDate;
   }

   /**
      Write-only city property. 
      @param aCity the city for which to report the local time
   */
   public void setCity(String aCity)
   {
      city = aCity;
   }

   /**
      Read-only available property.
      @return true if time zone information is available for 
      this city.
   */
   public boolean isAvailable()
   {
      return getTimeZone(city) != null;
   }

   /**
      Read-only time property.
      @return the formatted time
   */
   public String getTime()
   {
      TimeZone zone = getTimeZone(city);
      if (zone == null) return "not available";
      timeFormatter.setTimeZone(zone);
      String timeString = timeFormatter.format(theDate);
      return timeString;
   }

   /**
      Looks up the time zone for a city
      @param aCity the city for which to find the time zone
      @return the time zone or null if no match is found
   */
   private static TimeZone getTimeZone(String city)
   {
      String[] ids = TimeZone.getAvailableIDs();
      for (int i = 0; i < ids.length; i++)
         if (timeZoneIDmatch(ids[i], city))
            return TimeZone.getTimeZone(ids[i]);
      return null;
   }

   /**
      Checks whether a time zone ID matches a city
      @param id the time zone ID (e.g. "America/Los_Angeles")
      @param aCity the city to match (e.g. "Los Angeles")
      @return true if the ID and city match
   */
   private static boolean timeZoneIDmatch(String id, String city)
   {
      String idCity = id.substring(id.indexOf('/') + 1);
      return idCity.replace('_', ' ').equals(city);
   }

   private DateFormat timeFormatter;
   private Date theDate;
   private String city;
}
