import java.text.DateFormat;
import java.util.Date;
import java.util.TimeZone;
import java.sql.Connection;
import java.sql.Statement;
import java.sql.ResultSet;
import java.sql.SQLException;

/**
   This bean formats the local time of day for a given date
   and city, consulting a database in addition to the standard
   time zone ID list.
*/
public class ZoneDBBean
{ 
   /**
      Initializes the formatter.
   */
   public ZoneDBBean()
   {
      timeFormatter = DateFormat.getTimeInstance();
   }

   /**
      The city property. 
      @return the city for which to report the local time
   */
   public String getCity()
   {
      return city;
   }

   /**
      The city property. 
      @param aCity the city for which to report the local time
   */
   public void setCity(String aCity)
   {
      city = aCity;
   }

   /**
      Write-only date property. 
      @param aDate the date to be formatted.
   */
   public void setDate(Date aDate)
   {
      theDate = aDate;
   }

   /**
      Read-only time property.
      @return the formatted time
   */
   public String getTime() throws SQLException
   {
      TimeZone zone = null;
      zone = getTimeZoneDB();
      if (zone == null) // not found in database
         zone = getTimeZone(city); 
      if (zone == null) return "not available";
      timeFormatter.setTimeZone(zone);
      return timeFormatter.format(theDate);     
   }

   /**
      Looks up the time zone for a city in the database and
      the list of time zone IDs.
      @param aCity the city for which to find the time zone
      @return the time zone or null if no match is found
   */
   private TimeZone getTimeZoneDB() throws SQLException
   {
      Connection conn = null;
      try
      {
         conn = DataSourceBean.getConnection();
         Statement stat = conn.createStatement();
         String query = "SELECT Zone FROM CityZone" 
            + " WHERE City = '" + city + "'";
         ResultSet result = stat.executeQuery(query);
         if (result.next())
            return TimeZone.getTimeZone(result.getString(1));
         else
            return null;
      }
      finally
      {
         if (conn != null) conn.close();
      }
   }

   /**
      Looks up the time zone for a city in the list of time
      zone IDs
      @param aCity the city for which to find the time zone
      @return the time zone or null if no match is found
   */
   private static TimeZone getTimeZone(String city)
   {
      String[] ids = TimeZone.getAvailableIDs();
      for (int i = 0; i < ids.length; i++)
         if (timeZoneIDmatch(ids[i], city))
            return TimeZone.getTimeZone(ids[i]);
      return null;
   }

   /**
      Checks whether a time zone ID matches a city
      @param id the time zone ID (e.g. "America/Los_Angeles")
      @param aCity the city to match (e.g. "Los Angeles")
      @return true if the ID and city match
   */
   private static boolean timeZoneIDmatch(String id, String city)
   {
      String idCity = id.substring(id.indexOf('/') + 1);
      return idCity.replace('_', ' ').equals(city);
   }

   private Date theDate;
   private DateFormat timeFormatter;
   private String city;
}

